@@ -1,13 +1,16 @@
 {-# LANGUAGE GADTs #-}
 
 {- |
-Copyright: (c) 2018-2020 Kowainik
-SPDX-License-Identifier: MPL-2.0
-Maintainer: Kowainik <xrom.xkov@gmail.com>
+Module                  : Toml.Codec.BiMap.Conversion
+Copyright               : (c) 2018-2022 Kowainik
+SPDX-License-Identifier : MPL-2.0
+Maintainer              : Kowainik <xrom.xkov@gmail.com>
+Stability               : Stable
+Portability             : Portable
 
 Implementations of 'BiMap' for specific Haskell types and TOML
-values. Usually, you use codecs from the "Toml.Codec.Combinator"
-module. You may need to use these 'BiMap's instead of codecs in the
+values. Usually, you use codecs from the "Toml.Codec.Combinator" module.
+You may need to use these 'BiMap's instead of codecs in the
 following situations:
 
 1. When using 'Toml.Codec.Combinator.List.arrayOf' combinator (or similar).
@@ -60,6 +63,7 @@ module Toml.Codec.BiMap.Conversion
     , _Read
     , _TextBy
     , _Validate
+    , _Hardcoded
 
       -- * 'Key's
     , _KeyText
@@ -549,6 +553,28 @@ _EnumBounded :: (Show a, Enum a, Bounded a) => TomlBiMap a AnyValue
 _EnumBounded = _EnumBoundedText >>> _Text
 {-# INLINE _EnumBounded #-}
 
+
+{- | 'BiMap' for hardcoded values.
+It returns the same value in case of success and 'ArbitraryError' in other case.
+
+@since 1.3.2.0
+-}
+_Hardcoded :: forall a . (Show a, Eq a) => a -> TomlBiMap a a
+_Hardcoded a = BiMap
+    { forward = const (Right a)
+    , backward = checkValue
+    }
+  where
+      checkValue :: a -> Either TomlBiMapError a
+      checkValue v = if v == a
+          then Right v
+          else Left (ArbitraryError msg)
+        where
+          msg :: Text
+          msg = "Value '" <> T.pack (show v)
+              <> "' doesn't align with the hardcoded value '"
+              <> T.pack (show a) <> "'"
+
 ----------------------------------------------------------------------------
 -- Keys
 ----------------------------------------------------------------------------
